/***************************************************************************
    copyright            : (C) 2005 by Brian Nickel
    email                : brian.nickel@gmail.com
    based on             : tag.cpp from TagLib
 ***************************************************************************/

/***************************************************************************
 *   This library is free software; you can redistribute it and/or modify  *
 *   it  under the terms of the GNU Lesser General Public License version  *
 *   2.1 as published by the Free Software Foundation.                     *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
 *   USA                                                                   *
 ***************************************************************************/

namespace TagLib.Flac
{
   public class Tag : TagLib.Tag
   {
      //////////////////////////////////////////////////////////////////////////
      // private properties
      //////////////////////////////////////////////////////////////////////////
      private Ogg.XiphComment xiph;
      private Id3v2.Tag id3v2;
      private Id3v1.Tag id3v1;
      
      
      //////////////////////////////////////////////////////////////////////////
      // private properties
      //////////////////////////////////////////////////////////////////////////
      public Tag (Ogg.XiphComment xiph, Id3v2.Tag id3v2, Id3v1.Tag id3v1) : base ()
      {
         this.xiph  = xiph;
         this.id3v2 = id3v2;
         this.id3v1 = id3v1;
      }

      public Tag (Ogg.XiphComment xiph) : this (xiph, null, null)
      {
      }

      public override string Title
      {
         get
         {
            string output = null;
            if (xiph != null)                    output = xiph.Title;
            if (output == null && id3v2 != null) output = id3v2.Title;
            if (output == null && id3v1 != null) output = id3v1.Title;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Title  = value;
            if (id3v2 != null) id3v2.Title = value;
            if (id3v1 != null) id3v1.Title = value;
         }
      }

      public override string [] Artists
      {
         get
         {
            string [] output = null;
            if (xiph != null)                    output = xiph.Artists;
            if (output == null && id3v2 != null) output = id3v2.Artists;
            if (output == null && id3v1 != null) output = id3v1.Artists;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Artists  = value;
            if (id3v2 != null) id3v2.Artists = value;
            if (id3v1 != null) id3v1.Artists = value;
         }
      }

      public override string [] Performers
      {
         get
         {
            string [] output = null;
            if (xiph != null)                    output = xiph.Performers;
            if (output == null && id3v2 != null) output = id3v2.Performers;
            if (output == null && id3v1 != null) output = id3v1.Performers;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Performers  = value;
            if (id3v2 != null) id3v2.Performers = value;
            if (id3v1 != null) id3v1.Performers = value;
         }
      }

      public override string [] Composers
      {
         get
         {
            string [] output = null;
            if (xiph != null)                    output = xiph.Composers;
            if (output == null && id3v2 != null) output = id3v2.Composers;
            if (output == null && id3v1 != null) output = id3v1.Composers;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Composers  = value;
            if (id3v2 != null) id3v2.Composers = value;
            if (id3v1 != null) id3v1.Composers = value;
         }
      }

      public override string Album
      {
         get
         {
            string output = null;
            if (xiph != null)                    output = xiph.Album;
            if (output == null && id3v2 != null) output = id3v2.Album;
            if (output == null && id3v1 != null) output = id3v1.Album;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Album  = value;
            if (id3v2 != null) id3v2.Album = value;
            if (id3v1 != null) id3v1.Album = value;
         }
      }

      public override string Comment
      {
         get
         {
            string output = null;
            if (xiph != null)                    output = xiph.Comment;
            if (output == null && id3v2 != null) output = id3v2.Comment;
            if (output == null && id3v1 != null) output = id3v1.Comment;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Comment  = value;
            if (id3v2 != null) id3v2.Comment = value;
            if (id3v1 != null) id3v1.Comment = value;
         }
      }

      public override string [] Genres
      {
         get
         {
            string [] output = null;
            if (xiph != null)                    output = xiph.Genres;
            if (output == null && id3v2 != null) output = id3v2.Genres;
            if (output == null && id3v1 != null) output = id3v1.Genres;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Genres  = value;
            if (id3v2 != null) id3v2.Genres = value;
            if (id3v1 != null) id3v1.Genres = value;
         }
      }

      public override uint Year
      {
         get
         {
            uint output = 0;
            if (xiph != null)                 output = xiph.Year;
            if (output == 0 && id3v2 != null) output = id3v2.Year;
            if (output == 0 && id3v1 != null) output = id3v1.Year;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Year  = value;
            if (id3v2 != null) id3v2.Year = value;
            if (id3v1 != null) id3v1.Year = value;
         }
      }

      public override uint Track
      {
         get
         {
            uint output = 0;
            if (xiph != null)                 output = xiph.Track;
            if (output == 0 && id3v2 != null) output = id3v2.Track;
            if (output == 0 && id3v1 != null) output = id3v1.Track;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Track  = value;
            if (id3v2 != null) id3v2.Track = value;
            if (id3v1 != null) id3v1.Track = value;
         }
      }

      public override uint TrackCount
      {
         get
         {
            uint output = 0;
            if (xiph != null)                 output = xiph.TrackCount;
            if (output == 0 && id3v2 != null) output = id3v2.TrackCount;
            if (output == 0 && id3v1 != null) output = id3v1.TrackCount;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.TrackCount  = value;
            if (id3v2 != null) id3v2.TrackCount = value;
            if (id3v1 != null) id3v1.TrackCount = value;
         }
      }

      public override uint Disc
      {
         get
         {
            uint output = 0;
            if (xiph != null)                 output = xiph.Disc;
            if (output == 0 && id3v2 != null) output = id3v2.Disc;
            if (output == 0 && id3v1 != null) output = id3v1.Disc;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.Disc  = value;
            if (id3v2 != null) id3v2.Disc = value;
            if (id3v1 != null) id3v1.Disc = value;
         }
      }

      public override uint DiscCount
      {
         get
         {
            uint output = 0;
            if (xiph != null)                 output = xiph.DiscCount;
            if (output == 0 && id3v2 != null) output = id3v2.DiscCount;
            if (output == 0 && id3v1 != null) output = id3v1.DiscCount;
            return output;
         }
         set
         {
            if (xiph  != null) xiph.DiscCount  = value;
            if (id3v2 != null) id3v2.DiscCount = value;
            if (id3v1 != null) id3v1.DiscCount = value;
         }
      }
   }
}
