/***************************************************************************
    copyright            : (C) 2005 by Brian Nickel
    email                : brian.nickel@gmail.com
    based on             : tag.cpp from TagLib
 ***************************************************************************/

/***************************************************************************
 *   This library is free software; you can redistribute it and/or modify  *
 *   it  under the terms of the GNU Lesser General Public License version  *
 *   2.1 as published by the Free Software Foundation.                     *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
 *   USA                                                                   *
 ***************************************************************************/

namespace TagLib.Mpc
{
   public class CombinedTag : TagLib.Tag
   {
      //////////////////////////////////////////////////////////////////////////
      // private properties
      //////////////////////////////////////////////////////////////////////////
      private Ape.Tag ape;
      private Id3v1.Tag id3v1;
      
      
      //////////////////////////////////////////////////////////////////////////
      // private properties
      //////////////////////////////////////////////////////////////////////////
      public CombinedTag (Ape.Tag ape, Id3v1.Tag id3v1) : base ()
      {
         this.ape = ape;
         this.id3v1 = id3v1;
      }

      public override string Title
      {
         get
         {
            string output = null;
            if (ape != null)                     output = ape.Title;
            if (output == null && id3v1 != null) output = id3v1.Title;
            return output;
         }
         set
         {
            if (ape   != null) ape.Title   = value;
            if (id3v1 != null) id3v1.Title = value;
         }
      }

      public override string [] Artists
      {
         get
         {
            string [] output = null;
            if (ape != null)                     output = ape.Artists;
            if (output == null && id3v1 != null) output = id3v1.Artists;
            return output;
         }
         set
         {
            if (ape   != null) ape.Artists   = value;
            if (id3v1 != null) id3v1.Artists = value;
         }
      }

      public override string [] Performers
      {
         get
         {
            string [] output = null;
            if (ape != null)                     output = ape.Performers;
            if (output == null && id3v1 != null) output = id3v1.Performers;
            return output;
         }
         set
         {
            if (ape   != null) ape.Performers   = value;
            if (id3v1 != null) id3v1.Performers = value;
         }
      }

      public override string [] Composers
      {
         get
         {
            string [] output = null;
            if (ape != null)                     output = ape.Composers;
            if (output == null && id3v1 != null) output = id3v1.Composers;
            return output;
         }
         set
         {
            if (ape   != null) ape.Composers   = value;
            if (id3v1 != null) id3v1.Composers = value;
         }
      }

      public override string Album
      {
         get
         {
            string output = null;
            if (ape != null)                     output = ape.Album;
            if (output == null && id3v1 != null) output = id3v1.Album;
            return output;
         }
         set
         {
            if (ape   != null) ape.Album   = value;
            if (id3v1 != null) id3v1.Album = value;
         }
      }

      public override string Comment
      {
         get
         {
            string output = null;
            if (ape != null)                     output = ape.Comment;
            if (output == null && id3v1 != null) output = id3v1.Comment;
            return output;
         }
         set
         {
            if (ape   != null) ape.Comment   = value;
            if (id3v1 != null) id3v1.Comment = value;
         }
      }

      public override string [] Genres
      {
         get
         {
            string [] output = null;
            if (ape != null)                     output = ape.Genres;
            if (output == null && id3v1 != null) output = id3v1.Genres;
            return output;
         }
         set
         {
            if (ape   != null) ape.Genres   = value;
            if (id3v1 != null) id3v1.Genres = value;
         }
      }

      public override uint Year
      {
         get
         {
            uint output = 0;
            if (ape != null)                  output = ape.Year;
            if (output == 0 && id3v1 != null) output = id3v1.Year;
            return output;
         }
         set
         {
            if (ape   != null) ape.Year   = value;
            if (id3v1 != null) id3v1.Year = value;
         }
      }

      public override uint Track
      {
         get
         {
            uint output = 0;
            if (ape != null)                  output = ape.Track;
            if (output == 0 && id3v1 != null) output = id3v1.Track;
            return output;
         }
         set
         {
            if (ape   != null) ape.Track   = value;
            if (id3v1 != null) id3v1.Track = value;
         }
      }

      public override uint TrackCount
      {
         get
         {
            uint output = 0;
            if (ape != null)                  output = ape.TrackCount;
            if (output == 0 && id3v1 != null) output = id3v1.TrackCount;
            return output;
         }
         set
         {
            if (ape   != null) ape.TrackCount   = value;
            if (id3v1 != null) id3v1.TrackCount = value;
         }
      }

      public override uint Disc
      {
         get
         {
            uint output = 0;
            if (ape != null)                  output = ape.Disc;
            if (output == 0 && id3v1 != null) output = id3v1.Disc;
            return output;
         }
         set
         {
            if (ape   != null) ape.Disc   = value;
            if (id3v1 != null) id3v1.Disc = value;
         }
      }

      public override uint DiscCount
      {
         get
         {
            uint output = 0;
            if (ape != null)                  output = ape.DiscCount;
            if (output == 0 && id3v1 != null) output = id3v1.DiscCount;
            return output;
         }
         set
         {
            if (ape   != null) ape.DiscCount   = value;
            if (id3v1 != null) id3v1.DiscCount = value;
         }
      }
   }
}
