/***************************************************************************
    copyright            : (C) 2005 by Brian Nickel
    email                : brian.nickel@gmail.com
    based on             : mpegfile.cpp from TagLib
 ***************************************************************************/

/***************************************************************************
 *   This library is free software; you can redistribute it and/or modify  *
 *   it  under the terms of the GNU Lesser General Public License version  *
 *   2.1 as published by the Free Software Foundation.                     *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
 *   USA                                                                   *
 ***************************************************************************/

using System.Collections;
using System;

namespace TagLib.Mpeg
{
   public class Tag : TagLib.Tag
   {
      private Mpeg.File file;
      
      public Tag (Mpeg.File file) : base ()
      {
         this.file = file;
      }

      public override string Title
      {
         get
         {
            string output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Title;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Title;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Title = value;
            file.GetId3v1Tag (true).Title = value;
         }
      }

      public override string [] Artists
      {
         get
         {
            string [] output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Artists;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Artists;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Artists = value;
            file.GetId3v1Tag (true).Artists = value;
         }
      }

      public override string [] Performers
      {
         get
         {
            string [] output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Performers;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Performers;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Performers = value;
            file.GetId3v1Tag (true).Performers = value;
         }
      }

      public override string [] Composers
      {
         get
         {
            string [] output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Composers;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Composers;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Composers = value;
            file.GetId3v1Tag (true).Composers = value;
         }
      }

      public override string Album
      {
         get
         {
            string output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Album;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Album;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Album = value;
            file.GetId3v1Tag (true).Album = value;
         }
      }

      public override string Comment
      {
         get
         {
            string output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Comment;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Comment;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Comment = value;
            file.GetId3v1Tag (true).Comment = value;
         }
      }

      public override string [] Genres
      {
         get
         {
            string [] output = null;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Genres;
            if (output == null && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Genres;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Genres = value;
            file.GetId3v1Tag (true).Genres = value;
         }
      }

      public override uint Year
      {
         get
         {
            uint output = 0;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Year;
            if (output == 0 && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Year;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Year = value;
            file.GetId3v1Tag (true).Year = value;
         }
      }

      public override uint Track
      {
         get
         {
            uint output = 0;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Track;
            if (output == 0 && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Track;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Track = value;
            file.GetId3v1Tag (true).Track = value;
         }
      }

      public override uint TrackCount
      {
         get
         {
            uint output = 0;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().TrackCount;
            if (output == 0 && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().TrackCount;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).TrackCount = value;
            file.GetId3v1Tag (true).TrackCount = value;
         }
      }
      
      public override uint Disc
      {
         get
         {
            uint output = 0;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().Disc;
            if (output == 0 && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().Disc;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).Disc = value;
            file.GetId3v1Tag (true).Disc = value;
         }
      }
      
      public override uint DiscCount
      {
         get
         {
            uint output = 0;
            if (file.GetId3v2Tag () != null)
               output = file.GetId3v2Tag ().DiscCount;
            if (output == 0 && file.GetId3v1Tag () != null)
               output = file.GetId3v1Tag ().DiscCount;
            return output;
         }
         set
         {
            file.GetId3v2Tag (true).DiscCount = value;
            file.GetId3v1Tag (true).DiscCount = value;
         }
      }
   }
}
