public class ReadFiles
{
   public static void Main (string [] args)
   {
      if (args.Length == 0)
      {
         System.Console.WriteLine ("USAGE: ./read-files PATH ...");
         return;
      }
      
      System.Console.WriteLine ("********************************************************************************");
      foreach (string path in args)
      {
         System.Console.WriteLine ("");
         System.Console.WriteLine ("File:");
         System.Console.WriteLine ("   " + path);
         TagLib.File file = TagLib.File.Create (path);
         
         if (file == null)
         {
            System.Console.WriteLine ("");
            System.Console.WriteLine ("UNREADABLE FILE");
         }
         else
         {
            System.Console.WriteLine ("");
            System.Console.WriteLine ("Standard tagging information:");
            System.Console.WriteLine ("   Title:      " + file.Tag.Title);
            System.Console.WriteLine ("   Artists:    " + (file.Tag.Artists    == null ? "" : System.String.Join ("\n               ", file.Tag.Artists)));
            System.Console.WriteLine ("   Performers: " + (file.Tag.Performers == null ? "" : System.String.Join ("\n               ", file.Tag.Performers)));
            System.Console.WriteLine ("   Composers:  " + (file.Tag.Composers  == null ? "" : System.String.Join ("\n               ", file.Tag.Composers)));
            System.Console.WriteLine ("   Album:      " + file.Tag.Album);
            System.Console.WriteLine ("   Comment:    " + file.Tag.Comment);
            System.Console.WriteLine ("   Genres:     " + (file.Tag.Genres     == null ? "" : System.String.Join ("\n               ", file.Tag.Genres)));
            System.Console.WriteLine ("   Year:       " + file.Tag.Year);
            System.Console.WriteLine ("   Track:      " + file.Tag.Track);
            System.Console.WriteLine ("   TrackCount: " + file.Tag.TrackCount);
            System.Console.WriteLine ("   Disc:       " + file.Tag.Disc);
            System.Console.WriteLine ("   DiscCount:  " + file.Tag.DiscCount);

            System.Console.WriteLine ("");
            System.Console.WriteLine ("Audio properties:");
            System.Console.WriteLine ("   Length:         " + (file.AudioProperties.Length / 60) + ":" + (file.AudioProperties.Length % 60));
            System.Console.WriteLine ("   Bitrate:        " + file.AudioProperties.Bitrate);
            System.Console.WriteLine ("   SampleRate:     " + file.AudioProperties.SampleRate);
            System.Console.WriteLine ("   Channels:       " + file.AudioProperties.Channels);
            
            if (file.GetType () == typeof (TagLib.Mpeg.File))
            {
               TagLib.Mpeg.File mpeg_file = (TagLib.Mpeg.File) file;
               if (mpeg_file.GetId3v2Tag () != null)
               {
                  System.Console.WriteLine ("");
                  System.Console.WriteLine ("Id3v2 frames detected:");
                  foreach (TagLib.Id3v2.Frame frame in mpeg_file.GetId3v2Tag ().GetFrames ())
                  {
                     System.Console.WriteLine ("   CLASS: " + frame.GetType ());
                     System.Console.WriteLine ("   ID:    " + frame.FrameId);
                     System.Console.WriteLine ("   TEXT:  " + frame.ToString () + "\n");
                  }
               }
            }
         }
         
         System.Console.WriteLine ("");
         System.Console.WriteLine ("********************************************************************************");
      }
   }
}
